@@ -1,4 +1,4 @@
 from .chatbot import ChatBot
 from . import reddit_auth as RedditAuthentication
 from ._utils.frame_model import FrameType
-from ._api.models import CustomType
+from ._api.models import CustomType, MemberState
